Liferay.Loader.define('segments-web$date-fns@1.30.1/difference_in_days/index', ['module', 'exports', 'require', '../parse/index', '../difference_in_calendar_days/index', '../compare_asc/index'], function (module, exports, require) {
  var define = undefined;
  var parse = require('../parse/index');
  var differenceInCalendarDays = require('../difference_in_calendar_days/index');
  var compareAsc = require('../compare_asc/index');

  /**
   * @category Day Helpers
   * @summary Get the number of full days between the given dates.
   *
   * @description
   * Get the number of full days between the given dates.
   *
   * @param {Date|String|Number} dateLeft - the later date
   * @param {Date|String|Number} dateRight - the earlier date
   * @returns {Number} the number of full days
   *
   * @example
   * // How many full days are between
   * // 2 July 2011 23:00:00 and 2 July 2012 00:00:00?
   * var result = differenceInDays(
   *   new Date(2012, 6, 2, 0, 0),
   *   new Date(2011, 6, 2, 23, 0)
   * )
   * //=> 365
   */
  function differenceInDays(dirtyDateLeft, dirtyDateRight) {
    var dateLeft = parse(dirtyDateLeft);
    var dateRight = parse(dirtyDateRight);

    var sign = compareAsc(dateLeft, dateRight);
    var difference = Math.abs(differenceInCalendarDays(dateLeft, dateRight));
    dateLeft.setDate(dateLeft.getDate() - sign * difference);

    // Math.abs(diff in full days - diff in calendar days) === 1 if last calendar day is not full
    // If so, result must be decreased by 1 in absolute value
    var isLastDayNotFull = compareAsc(dateLeft, dateRight) === -sign;
    return sign * (difference - isLastDayNotFull);
  }

  module.exports = differenceInDays;
});
//# sourceMappingURL=index.js.map