Liferay.Loader.define('segments-web$date-fns@1.30.1/difference_in_years/index', ['module', 'exports', 'require', '../parse/index', '../difference_in_calendar_years/index', '../compare_asc/index'], function (module, exports, require) {
  var define = undefined;
  var parse = require('../parse/index');
  var differenceInCalendarYears = require('../difference_in_calendar_years/index');
  var compareAsc = require('../compare_asc/index');

  /**
   * @category Year Helpers
   * @summary Get the number of full years between the given dates.
   *
   * @description
   * Get the number of full years between the given dates.
   *
   * @param {Date|String|Number} dateLeft - the later date
   * @param {Date|String|Number} dateRight - the earlier date
   * @returns {Number} the number of full years
   *
   * @example
   * // How many full years are between 31 December 2013 and 11 February 2015?
   * var result = differenceInYears(
   *   new Date(2015, 1, 11),
   *   new Date(2013, 11, 31)
   * )
   * //=> 1
   */
  function differenceInYears(dirtyDateLeft, dirtyDateRight) {
    var dateLeft = parse(dirtyDateLeft);
    var dateRight = parse(dirtyDateRight);

    var sign = compareAsc(dateLeft, dateRight);
    var difference = Math.abs(differenceInCalendarYears(dateLeft, dateRight));
    dateLeft.setFullYear(dateLeft.getFullYear() - sign * difference);

    // Math.abs(diff in full years - diff in calendar years) === 1 if last calendar year is not full
    // If so, result must be decreased by 1 in absolute value
    var isLastYearNotFull = compareAsc(dateLeft, dateRight) === -sign;
    return sign * (difference - isLastYearNotFull);
  }

  module.exports = differenceInYears;
});
//# sourceMappingURL=index.js.map