Liferay.Loader.define('segments-web$lodash@4.17.21/xorWith', ['module', 'exports', 'require', './_arrayFilter', './_baseRest', './_baseXor', './isArrayLikeObject', './last'], function (module, exports, require) {
  var define = undefined;
  var arrayFilter = require('./_arrayFilter'),
      baseRest = require('./_baseRest'),
      baseXor = require('./_baseXor'),
      isArrayLikeObject = require('./isArrayLikeObject'),
      last = require('./last');

  /**
   * This method is like `_.xor` except that it accepts `comparator` which is
   * invoked to compare elements of `arrays`. The order of result values is
   * determined by the order they occur in the arrays. The comparator is invoked
   * with two arguments: (arrVal, othVal).
   *
   * @static
   * @memberOf _
   * @since 4.0.0
   * @category Array
   * @param {...Array} [arrays] The arrays to inspect.
   * @param {Function} [comparator] The comparator invoked per element.
   * @returns {Array} Returns the new array of filtered values.
   * @example
   *
   * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
   * var others = [{ 'x': 1, 'y': 1 }, { 'x': 1, 'y': 2 }];
   *
   * _.xorWith(objects, others, _.isEqual);
   * // => [{ 'x': 2, 'y': 1 }, { 'x': 1, 'y': 1 }]
   */
  var xorWith = baseRest(function (arrays) {
    var comparator = last(arrays);
    comparator = typeof comparator == 'function' ? comparator : undefined;
    return baseXor(arrayFilter(arrays, isArrayLikeObject), undefined, comparator);
  });

  module.exports = xorWith;
});
//# sourceMappingURL=xorWith.js.map